summaryrefslogtreecommitdiffstats
path: root/scripts/kdemangen.pl
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/kdemangen.pl')
-rwxr-xr-xscripts/kdemangen.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/kdemangen.pl b/scripts/kdemangen.pl
index 59680b20..0032040a 100755
--- a/scripts/kdemangen.pl
+++ b/scripts/kdemangen.pl
@@ -44,7 +44,7 @@
# 3 run "man ./kstars.1" to check out the generated page..
# PROBLEMS:
# Only works for full TDE applications that use KCmdLineArgs (
# inherent to my approach, but most KDE apps fulfill this requirement
# )
@@ -179,7 +179,7 @@ sub sortoptionsfromnroff {
sub usage
{
- print "This script generates a nice manual page for a KDE app which uses KCmdLineArgs..\n";
+ print "This script generates a nice manual page for a KDE app which uses TDECmdLineArgs..\n";
print "USAGE: $0 app\n";
print "There's more information about how to use this script in the comments at the front of the source..\n"
};
@@ -44,7 +44,7 @@
# 3 run "man ./kstars.1" to check out the generated page..
# PROBLEMS:
-# Only works for full TDE applications that use KCmdLineArgs (
+# Only works for full TDE applications that use TDECmdLineArgs (
# inherent to my approach, but most KDE apps fulfill this requirement
# )